==> jc-1.4.0.tar.gz: soot/jimple/toolkits/pointer/SideEffectTagger__24UniqueRWSets.h <==
// public class soot.jimple.toolkits.pointer.SideEffectTagger$UniqueRWSets

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class dc3408330e7d2991 soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets_H_
#define _JC_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_jimple_toolkits_pointer_RWSet$object;
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vmethods	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtable	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method$_init$d4751e1f0bea927c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *);

// Virtual methods
extern struct _jc_soot_jimple_toolkits_pointer_RWSet$object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method$getUnique$babdf2fa61a7cbb2(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *);
extern jshort _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method$indexOf$e36066f1fa22d55c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method_info$getUnique$babdf2fa61a7cbb2;
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method_info$indexOf$e36066f1fa22d55c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method_info$iterator$3cc91493d50f531c;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vmethods {
	struct _jc_soot_jimple_toolkits_pointer_RWSet$object	*(*getUnique$babdf2fa61a7cbb2)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *);
	jshort	(*indexOf$e36066f1fa22d55c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *);
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vmethods	soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_refs {
	struct _jc_java_util_ArrayList$object	*l;
	struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$refs {
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_refs	soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_nonrefs	soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object {
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/pointer/SideEffectTagger__24UniqueRWSets.h <==
// public class soot.jimple.toolkits.pointer.SideEffectTagger$UniqueRWSets

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class dc3408330e7d2991 soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets_H_
#define _JC_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_util_ArrayList$object;
struct _jc_java_util_Iterator$object;
struct _jc_soot_jimple_toolkits_pointer_RWSet$object;
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$refs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$refs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$nonrefs	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$nonrefs;
typedef struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object;

typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vmethods	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vmethods;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtable	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtable;
typedef const struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method$_init$d4751e1f0bea927c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_soot_jimple_toolkits_pointer_RWSet$object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method$getUnique$babdf2fa61a7cbb2(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *) _JC_JCNI_ATTR;
extern jshort _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method$indexOf$e36066f1fa22d55c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method$iterator$3cc91493d50f531c(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method_info$getUnique$babdf2fa61a7cbb2;
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method_info$indexOf$e36066f1fa22d55c;
extern _jc_method _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$method_info$iterator$3cc91493d50f531c;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vmethods {
	struct _jc_soot_jimple_toolkits_pointer_RWSet$object	*(*getUnique$babdf2fa61a7cbb2)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *) _JC_JCNI_ATTR;
	jshort	(*indexOf$e36066f1fa22d55c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *, struct _jc_soot_jimple_toolkits_pointer_RWSet$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*iterator$3cc91493d50f531c)(_jc_env *, struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vmethods	soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets;
};

// Vtype
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_refs {
	struct _jc_java_util_ArrayList$object	*l;
	struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger$object	*this__240;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$refs {
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_refs	soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$sub_nonrefs	soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$object {
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype	*vtype;
	_jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$vtype _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets$class_object;

#endif	/* _JC_soot_jimple_toolkits_pointer_SideEffectTagger__24UniqueRWSets_H_ */
